@@ -35,6 +35,7 @@ const GeocodeService = imports.geocodeService;
 const MainWindow = imports.mainWindow;
 const Maps = imports.gi.GnomeMaps;
 const NotificationManager = imports.notificationManager;
+const OSMEdit = imports.osmEdit;
 const PlaceStore = imports.placeStore;
 const RouteService = imports.routeService;
 const Settings = imports.settings;
@@ -51,6 +52,7 @@ let geocodeService = null;
 let networkMonitor = null;
 let checkInManager = null;
 let contactStore = null;
+let osmEdit = null;
 
 const Application = new Lang.Class({
     Name: 'Application',
@@ -147,6 +149,10 @@ const Application = new Lang.Class({
         this._mainWindow.destroy();
     },
 
+    _onOsmAccountSetupActivate: function() {
+        osmEdit.showAccountDialog(this._mainWindow, false);
+    },
+
     _addContacts: function() {
         contactStore.get_contacts().forEach(function(contact) {
             contact.geocode(function() {
@@ -205,6 +211,9 @@ const Application = new Lang.Class({
             'show-contact': {
                 paramType: 's',
                 onActivate: this._onShowContactActivate.bind(this)
+            },
+            'osm-account-setup': {
+                onActivate: this._onOsmAccountSetupActivate.bind(this)
             }
         });
 
@@ -225,6 +234,7 @@ const Application = new Lang.Class({
         checkInManager = new CheckIn.CheckInManager();
         contactStore = new Maps.ContactStore();
         contactStore.load();
+        osmEdit = new OSMEdit.OSMEdit();
     },
 
     _createWindow: function() {
@@ -234,7 +244,8 @@ const Application = new Lang.Class({
         let overlay = new Gtk.Overlay({ visible: true, can_focus: false });
         notificationManager = new NotificationManager.NotificationManager(overlay);
         this._mainWindow = new MainWindow.MainWindow({ application: this,
-                                                       overlay: overlay });
+                                                       overlay: overlay,
+                                                       opening: this._opening });
         this._mainWindow.connect('destroy', this._onWindowDestroy.bind(this));
     },
 
@@ -253,15 +264,36 @@ const Application = new Lang.Class({
         this._mainWindow.present();
     },
 
-    vfunc_open: function(files) {
-        this.activate();
-        let content_type = Gio.content_type_guess(files[0].get_uri(), null)[0];
+    _openInternal: function(file) {
+        let uri = file.get_uri();
+
+        if (GLib.uri_parse_scheme(uri) === 'geo') {
+            /* we get an uri that looks like geo:///lat,lon, remove slashes */
+            let geoURI = uri.replace(/\//g, '');
+            this._mainWindow.mapView.goToGeoURI(geoURI);
+            return;
+        }
+
+        let content_type = Gio.content_type_guess(uri, null)[0];
         if (content_type === 'application/vnd.geo+json' ||
             content_type === 'application/json') {
-            this._mainWindow.mapView.openGeoJSON(files[0]);
+            this._mainWindow.mapView.openGeoJSON(file);
+            return;
         }
     },
 
+    vfunc_open: function(files) {
+        this._opening = true;
+        this.activate();
+
+        let mapView = this._mainWindow.mapView;
+        if (mapView.view.realized)
+            this._openInternal(files[0]);
+        else
+            mapView.view.connect('notify::realized',
+                                 this._openInternal.bind(this, files[0]));
+    },
+
     _onWindowDestroy: function(window) {
         this._mainWindow = null;
     }
