@@ -29,6 +29,8 @@ const Location = imports.location;
 const Place = imports.place;
 const PlaceMarker = imports.placeMarker;
 const Utils = imports.utils;
+const GeoJSONStyle = imports.geoJSONStyle;
+
 
 const TILE_SIZE = 256;
 
@@ -36,11 +38,6 @@ const TileFeature = { POINT: 1,
                       LINESTRING: 2,
                       POLYGON: 3 };
 
-const PolygonColor = { RED: 0.37,
-                       GREEN: 0.62,
-                       BLUE: 0.87,
-                       ALPHA: 0.25 };
-
 const GeoJSONSource = new Lang.Class({
     Name: 'GeoJSONSource',
     Extends: Champlain.TileSource,
@@ -119,6 +116,28 @@ const GeoJSONSource = new Lang.Class({
         }).bind(this));
     },
 
+    _parsePoint: function(coordinates, properties) {
+        let name = null;
+        if (properties)
+            name = properties.name;
+
+        this._validate(coordinates);
+        this._bbox.extend(coordinates[1],
+                          coordinates[0]);
+
+        let location = new Location.Location({
+            latitude: coordinates[1],
+            longitude: coordinates[0]
+        });
+
+        let place = new Place.Place({ name: name,
+                                      store: false,
+                                      location: location });
+        let placeMarker = new PlaceMarker.PlaceMarker({ place: place,
+                                                        mapView: this._mapView });
+        this._markerLayer.add_marker(placeMarker);
+    },
+
     _parseGeometry: function(geometry, properties) {
         if(!geometry)
             throw new Error(_("parse error"));
@@ -145,28 +164,13 @@ const GeoJSONSource = new Lang.Class({
             break;
 
         case 'Point':
-            let name = null;
-            if (properties)
-                name = properties.name;
-
-            this._validate(geometry.coordinates);
-            this._bbox.extend(geometry.coordinates[1],
-                              geometry.coordinates[0]);
-
-            let location = new Location.Location({
-                latitude: geometry.coordinates[1],
-                longitude: geometry.coordinates[0]
-            });
-
-            let place = new Place.Place({ name: name,
-                                          store: false,
-                                          location: location });
-            let placeMarker = new PlaceMarker.PlaceMarker({ place: place,
-                                                            mapView: this._mapView });
-            this._markerLayer.add_marker(placeMarker);
+            this._parsePoint(geometry.coordinates, properties);
             break;
 
         case 'MultiPoint':
+            geometry.coordinates.forEach((function(coordinate, properties) {
+                this._parsePoint(coordinate,properties);
+            }).bind(this));
             break;
 
         default:
@@ -230,16 +234,22 @@ const GeoJSONSource = new Lang.Class({
             cr.setOperator(Cairo.Operator.CLEAR);
             cr.paint();
             cr.setOperator(Cairo.Operator.OVER);
-            cr.setLineWidth(1);
+            cr.setFillRule(Cairo.FillRule.EVEN_ODD);
 
             tileJSON.features.forEach(function(feature) {
                 if (feature.type === TileFeature.POINT)
                     return;
 
+                let geoJSONStyleObj = GeoJSONStyle.GeoJSONStyle.parseSimpleStyle(feature.tags);
+
                 feature.geometry.forEach(function(geometry) {
                     let first = true;
                     cr.moveTo(0, 0);
-                    cr.setSourceRGB(0, 0, 0);
+                    cr.setLineWidth(geoJSONStyleObj.lineWidth);
+                    cr.setSourceRGBA(geoJSONStyleObj.color.red,
+                                     geoJSONStyleObj.color.green,
+                                     geoJSONStyleObj.color.blue,
+                                     geoJSONStyleObj.alpha);
 
                     geometry.forEach(function(coord) {
                         if (first) {
@@ -253,10 +263,10 @@ const GeoJSONSource = new Lang.Class({
                 if (feature.type === TileFeature.POLYGON) {
                     cr.closePath();
                     cr.strokePreserve();
-                    cr.setSourceRGBA(PolygonColor.RED,
-                                     PolygonColor.GREEN,
-                                     PolygonColor.BLUE,
-                                     PolygonColor.ALPHA);
+                    cr.setSourceRGBA(geoJSONStyleObj.fillColor.red,
+                                     geoJSONStyleObj.fillColor.green,
+                                     geoJSONStyleObj.fillColor.blue,
+                                     geoJSONStyleObj.fillAlpha);
                     cr.fill();
                 } else {
                     cr.stroke();
